@@ -160,7 +160,7 @@ def setup(settings_path=None, **settings_patches):
     #    'Match Group beanstalk',
     #    '       ForceCommand /usr/bin/bs_ssh_entry',
     #]
-    #local(sed('$ a\\\n{command}'.format(command='\\n'.join(new_lines)), sshd_config))
+    #local(sed('$ a\\{command}'.format(command='\\n'.join(new_lines)), sshd_config))
     local(sed('/^AllowGroups wheel$/cAllowGroups wheel beanstalk', sshd_config))  # TODO: More general form
 
     # Apache conf
@@ -275,8 +275,8 @@ def create_app(project_name, settings_path=None, **settings_patches):
             '#' + '-' * 20,
             ' ',
         ]
-        sed_command = '\\\n'.join(commands)
-        local(sed('$a\\{command}'.format(command=sed_command), apache_conf_path()))
+        sed_command = '\\n'.join(commands)
+        local(sed('$ a\\{command}'.format(command=sed_command), apache_conf_path()))
         local('sudo /usr/sbin/httpd_reload')
 
     port_file_path = os.path.join(project_base_path(project_name), '%d.port' % uwsgi_port)
