@@ -2,18 +2,18 @@ import hashlib
 from fabric.api import *
 from ground_soil.filesystem import rsync
 from beanstalk.decorators import beanstalk_role
-from beanstalk.tasks.utils import load_role_settings as load_beanstalk_settings, load_web_servers
+from beanstalk.tasks.utils import load_role_settings, load_web_servers
 from beanstalk.console.titles import tool_title
 from beanstalk.validator import validate_file_existence
 
 
 @task
 @beanstalk_role('app')
-def add(**settings_patches):
+def add(settings_path=None, **settings_patches):
     """Add current user to beanstalk-stack server
     """
     # Load settings
-    load_beanstalk_settings(**settings_patches)
+    load_role_settings(additional_settings_path=settings_path, **settings_patches)
     load_web_servers()
 
     print tool_title('Beanstalk-Stack users tool')
